==> activity-center-api-3.3.26-sources.jar: cn/com/duiba/activity/center/api/dto/happycodenew/HappyCodeItemBasicDto.java <==
package cn.com.duiba.activity.center.api.dto.happycodenew;

import cn.com.duiba.activity.center.api.enums.happycodenew.ItemBasicStatusEnum;

import java.io.Serializable;
import java.util.Date;

/**
 * @Author chenxiangge
 * @Date 2019/3/29
 */
public class HappyCodeItemBasicDto implements Serializable {
    private static final long serialVersionUID = 21394597339308877L;

    private Long id;
    /**
     * 对应开心码活动id
     */
    private Long actId;
    /**
     * 应用id
     */
    private Long appId;
    /**
     * 开始的日期 yyyy-mm-dd
     */
    private Date startDate;
    /**
     * 周期
     */
    private Integer actCycle;
    /**
     * 开始夺宝时间点
     */
    private String startTime;
    /**
     * 结束夺宝时间点
     */
    private String endTime;
    /**
     * 开奖时间点
     */
    private String takePrizeTime;
    /**
     * 自动续期期数
     */
    private Integer autoContinueCount;
    /**
     * 达标人数
     */
    private Integer expectedAwardAmount;
    /**
     * 单人本期购买上限
     */
    private Integer maxPurchaseAmount;
    /**
     * 当前期次序号
     */
    private Integer currentPayload;
    /**
     * 当前期次id
     */
    private Long currentPhaseId;
    /**
     * 单次抽码消耗积分数量
     */
    private Integer credits;
    /**
     * 赛事状态 - 详见后续枚举类型
     */
    private ItemBasicStatusEnum basicStatus;
    /**
     * 开发者商品id
     */
    private Long appItemId;
    /**
     * 开发者商品名称
     */
    private String appItemName;
    /**
     * 开发者商品类型
     */
    private String appItemType;
    /**
     * 开发者商品图片
     */
    private String appItemPic;
    /**
     * 开发者商品划线价
     */
    private Long facePrice;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getActId() {
        return actId;
    }

    public void setActId(Long actId) {
        this.actId = actId;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public String getTakePrizeTime() {
        return takePrizeTime;
    }

    public void setTakePrizeTime(String takePrizeTime) {
        this.takePrizeTime = takePrizeTime;
    }

    public Integer getAutoContinueCount() {
        return autoContinueCount;
    }

    public void setAutoContinueCount(Integer autoContinueCount) {
        this.autoContinueCount = autoContinueCount;
    }

    public Integer getExpectedAwardAmount() {
        return expectedAwardAmount;
    }

    public void setExpectedAwardAmount(Integer expectedAwardAmount) {
        this.expectedAwardAmount = expectedAwardAmount;
    }

    public Integer getMaxPurchaseAmount() {
        return maxPurchaseAmount;
    }

    public void setMaxPurchaseAmount(Integer maxPurchaseAmount) {
        this.maxPurchaseAmount = maxPurchaseAmount;
    }

    public Integer getCredits() {
        return credits;
    }

    public void setCredits(Integer credits) {
        this.credits = credits;
    }

    public ItemBasicStatusEnum getBasicStatus() {
        return basicStatus;
    }

    public void setBasicStatus(ItemBasicStatusEnum basicStatus) {
        this.basicStatus = basicStatus;
    }

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public String getAppItemName() {
        return appItemName;
    }

    public void setAppItemName(String appItemName) {
        this.appItemName = appItemName;
    }

    public String getAppItemType() {
        return appItemType;
    }

    public void setAppItemType(String appItemType) {
        this.appItemType = appItemType;
    }

    public String getAppItemPic() {
        return appItemPic;
    }

    public void setAppItemPic(String appItemPic) {
        this.appItemPic = appItemPic;
    }

    public Long getFacePrice() {
        return facePrice;
    }

    public void setFacePrice(Long facePrice) {
        this.facePrice = facePrice;
    }

    public Integer getCurrentPayload() {
        return currentPayload;
    }

    public void setCurrentPayload(Integer currentPayload) {
        this.currentPayload = currentPayload;
    }

    public Long getCurrentPhaseId() {
        return currentPhaseId;
    }

    public void setCurrentPhaseId(Long currentPhaseId) {
        this.currentPhaseId = currentPhaseId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Integer getActCycle() {
        return actCycle;
    }

    public void setActCycle(Integer actCycle) {
        this.actCycle = actCycle;
    }
}

==> activity-center-api-3.6.34-sources.jar: cn/com/duiba/activity/center/api/dto/happycodenew/HappyCodeItemBasicDto.java <==
package cn.com.duiba.activity.center.api.dto.happycodenew;

import cn.com.duiba.activity.center.api.enums.happycodenew.ItemBasicStatusEnum;

import java.io.Serializable;
import java.util.Date;

/**
 * @Author chenxiangge
 * @Date 2019/3/29
 */
public class HappyCodeItemBasicDto implements Serializable {
    private static final long serialVersionUID = 21394597339308877L;

    private Long id;
    /**
     * 对应开心码活动id
     */
    private Long actId;
    /**
     * 应用id
     */
    private Long appId;
    /**
     * 开始的日期 yyyy-mm-dd
     */
    private Date startDate;
    /**
     * 周期
     */
    private Integer actCycle;
    /**
     * 开始夺宝时间点
     */
    private String startTime;
    /**
     * 结束夺宝时间点
     */
    private String endTime;
    /**
     * 开奖时间点
     */
    private String takePrizeTime;
    /**
     * 自动续期期数
     */
    private Integer autoContinueCount;
    /**
     * 达标人数
     */
    private Integer expectedAwardAmount;
    /**
     * 单人本期购买上限
     */
    private Integer maxPurchaseAmount;
    /**
     * 当前期次序号
     */
    private Integer currentPayload;
    /**
     * 当前期次id
     */
    private Long currentPhaseId;
    /**
     * 单次抽码消耗积分数量
     */
    private Integer credits;
    /**
     * 赛事状态 - 详见后续枚举类型
     */
    private ItemBasicStatusEnum basicStatus;
    /**
     * 开发者商品id
     */
    private Long appItemId;
    /**
     * 开发者商品名称
     */
    private String appItemName;
    /**
     * 开发者商品类型
     */
    private String appItemType;
    /**
     * 开发者商品图片
     */
    private String appItemPic;
    /**
     * 开发者商品划线价
     */
    private Long facePrice;
    /**
     * 虚拟商品标识符
     */
    private String merchantCoding;

    /**
     * 发奖数量
     */
    private Integer prizeQuantity;

    public Integer getPrizeQuantity() {
        return prizeQuantity;
    }

    public void setPrizeQuantity(Integer prizeQuantity) {
        this.prizeQuantity = prizeQuantity;
    }

    public String getMerchantCoding() {
        return merchantCoding;
    }

    public void setMerchantCoding(String merchantCoding) {
        this.merchantCoding = merchantCoding;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getActId() {
        return actId;
    }

    public void setActId(Long actId) {
        this.actId = actId;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public String getTakePrizeTime() {
        return takePrizeTime;
    }

    public void setTakePrizeTime(String takePrizeTime) {
        this.takePrizeTime = takePrizeTime;
    }

    public Integer getAutoContinueCount() {
        return autoContinueCount;
    }

    public void setAutoContinueCount(Integer autoContinueCount) {
        this.autoContinueCount = autoContinueCount;
    }

    public Integer getExpectedAwardAmount() {
        return expectedAwardAmount;
    }

    public void setExpectedAwardAmount(Integer expectedAwardAmount) {
        this.expectedAwardAmount = expectedAwardAmount;
    }

    public Integer getMaxPurchaseAmount() {
        return maxPurchaseAmount;
    }

    public void setMaxPurchaseAmount(Integer maxPurchaseAmount) {
        this.maxPurchaseAmount = maxPurchaseAmount;
    }

    public Integer getCredits() {
        return credits;
    }

    public void setCredits(Integer credits) {
        this.credits = credits;
    }

    public ItemBasicStatusEnum getBasicStatus() {
        return basicStatus;
    }

    public void setBasicStatus(ItemBasicStatusEnum basicStatus) {
        this.basicStatus = basicStatus;
    }

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public String getAppItemName() {
        return appItemName;
    }

    public void setAppItemName(String appItemName) {
        this.appItemName = appItemName;
    }

    public String getAppItemType() {
        return appItemType;
    }

    public void setAppItemType(String appItemType) {
        this.appItemType = appItemType;
    }

    public String getAppItemPic() {
        return appItemPic;
    }

    public void setAppItemPic(String appItemPic) {
        this.appItemPic = appItemPic;
    }

    public Long getFacePrice() {
        return facePrice;
    }

    public void setFacePrice(Long facePrice) {
        this.facePrice = facePrice;
    }

    public Integer getCurrentPayload() {
        return currentPayload;
    }

    public void setCurrentPayload(Integer currentPayload) {
        this.currentPayload = currentPayload;
    }

    public Long getCurrentPhaseId() {
        return currentPhaseId;
    }

    public void setCurrentPhaseId(Long currentPhaseId) {
        this.currentPhaseId = currentPhaseId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Integer getActCycle() {
        return actCycle;
    }

    public void setActCycle(Integer actCycle) {
        this.actCycle = actCycle;
    }
}
